@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2020-12-23 17:07:18
+:LastEditTime: 2021-11-03 16:09:14
 :LastEditors: ChenXiaolei
 :Description: 数据库基础操作类
 """
@@ -103,8 +103,8 @@ class BaseModel:
             group_by = " GROUP BY "+group_by
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
-        if limit and limit.strip() != '':
-            limit = " LIMIT "+limit
+        if limit:
+            limit = " LIMIT "+str(limit)
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         list_row = self.db.fetch_all_rows(sql, params)
         return self.__row_entity_list(list_row)
@@ -139,7 +139,11 @@ class BaseModel:
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {str(int(page_index) * int(page_size))},{str(page_size)};"
         list_row = self.db.fetch_all_rows(sql, params)
 
-        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
+        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+
+        if group_by:
+            sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
+
         row = self.db.fetch_one_row(sql, params)
 
         if row and 'count' in row and int(row['count']) > 0:
@@ -196,9 +200,13 @@ class BaseModel:
             group_by = " GROUP BY "+group_by
         if not field:
             field = self.primary_key_field
-        sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by};"
+        sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by}"
+
+        if group_by:
+            sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table;"
+
         list_row = self.db.fetch_one_row(sql, params)
-        
+
         if list_row and 'count' in list_row:
             return list_row['count']
         return 0
@@ -228,11 +236,11 @@ class BaseModel:
                 else:
                     return False
 
-    def add_entity(self, model, ignore=False):
+    def add_entity(self, model, ignore=False, return_increment_primary=True):
         """
         :Description: 数据入库
         :param model: 模型实体 
-        :return: 如果主键为自增ID，返回主键值
+        :return: 非事务:如果主键为自增ID，返回自增ID
         :last_editors: ChenXiaolei
         """
         field_list = self.model_obj.get_field_list()
@@ -258,7 +266,8 @@ class BaseModel:
             self.db_transaction.transaction_list.append(transaction_item)
             return True
         else:
-            list_row = self.db.insert(sql, tuple(param))
+            list_row = self.db.insert(sql, tuple(
+                param), return_increment_primary)
             return list_row
 
     def add_list(self, model_list, ignore=False, transaction=False):
@@ -305,12 +314,61 @@ class BaseModel:
                 return False
         return True
 
-    def add_update_entity(self, model, update_sql, params=None):
+    def add_values(self, model_list, ignore=False):
+        """
+        :description: 一次性数据写入(insert into... values(...),(...),(...);)
+        :param model_list: 数据模型列表
+        :param ignore: 忽略已存在的记录
+        :return 成功True 失败False
+        :last_editors: ChenXiaolei
+        """
+        if not model_list or len(model_list) == 0:
+            return False
+        field_list = self.model_obj.get_field_list()
+        if len(field_list) == 0:
+            return False
+
+        insert_field_str = ""
+        for field_str in field_list:
+            if str(field_str).lower() == self.primary_key_field.lower():
+                continue
+            insert_field_str += str(field_str + ",")
+
+        insert_field_str = insert_field_str.rstrip(',')
+
+        sql = f"INSERT{' IGNORE' if ignore else ''} INTO {self.table_name}({insert_field_str}) VALUES "
+
+        param = []
+        for model in model_list:
+            insert_value_str = ""
+
+            for field_str in field_list:
+                param_value = str(getattr(model, field_str))
+                if str(field_str).lower() == self.primary_key_field.lower():
+                    continue
+                insert_value_str += "%s,"
+                param.append(param_value)
+            insert_value_str = insert_value_str.rstrip(',')
+            sql += f"({insert_value_str}),"
+
+        sql = sql.rstrip(',')+";"
+
+        if self.is_transaction():
+            sql_item = {}
+            sql_item["sql"] = sql
+            sql_item["params"] = tuple(param)
+            self.db_transaction.transaction_list.append(sql_item)
+        else:
+            self.db.insert(sql, tuple(param), False)
+        return True
+
+    def add_update_entity(self, model, update_sql, params=None, return_increment_primary=True):
         """
         :Description: 数据入库,遇到主键冲突则更新指定字段
         :param model: 模型实体 
         :param update_sql: 如果主键冲突则执行的更新sql语句
         :param params: 参数化查询参数
+        :param return_increment_primary: True=返回自增主键ID False=返回影响行数
         :return: 如果主键为自增ID，返回主键值
         :last_editors: ChenXiaolei
         """
@@ -339,13 +397,63 @@ class BaseModel:
             self.db_transaction.transaction_list.append(transaction_item)
             return True
         else:
-            list_row = self.db.insert(sql, tuple(param))
+            list_row = self.db.insert(sql, tuple(
+                param), return_increment_primary)
             return list_row
 
-    def update_entity(self, model, field_list=None):
+    def add_update_whole_entity(self, model, exclude_duplicate_key_field_list=None, return_increment_primary=True):
+        """
+        :Description: 数据入库,遇到主键冲突则更新指定字段
+        :param model: 模型实体 
+        :param exclude_duplicate_key_field_list: 触发唯一键时需排除更新的字段列表
+        :param return_increment_primary: True=返回自增主键ID False=返回影响行数
+        :return: 如果主键为自增ID，返回主键值
+        :last_editors: ChenXiaolei
+        """
+        field_list = self.model_obj.get_field_list()
+        if len(field_list) == 0:
+            return 0
+        insert_field_str = ""
+        insert_value_str = ""
+        update_sql = ""
+        param = []
+        update_param = []
+        for field_str in field_list:
+            param_value = str(getattr(model, field_str))
+            if str(field_str).lower() == self.primary_key_field.lower() and param_value == "0":
+                continue
+            insert_field_str += str(field_str + ",")
+            insert_value_str += "%s,"
+            param.append(param_value)
+
+            if exclude_duplicate_key_field_list and field_str not in exclude_duplicate_key_field_list:
+                update_sql += f"{field}=%s,"
+                update_param.append(param_value)
+
+        insert_field_str = insert_field_str.rstrip(',')
+        insert_value_str = insert_value_str.rstrip(',')
+        update_sql = update_sql.rstrip(',')
+
+        param.extend(update_param)
+
+        sql = f"INSERT INTO {self.table_name}({insert_field_str}) VALUE({insert_value_str}) ON DUPLICATE KEY UPDATE {update_sql};"
+        if self.is_transaction():
+            transaction_item = {}
+            transaction_item["sql"] = sql
+            transaction_item["params"] = tuple(param)
+            self.db_transaction.transaction_list.append(transaction_item)
+            return True
+        else:
+            list_row = self.db.insert(sql, tuple(
+                param), return_increment_primary)
+            return list_row
+
+    def update_entity(self, model, field_list=None, exclude_field_list=None):
         """
         :Description: 根据模型的主键ID，更新字段的值
         :param model: 模型实体
+        :param field_list: 需要更新的字段列表
+        :param exclude_field_list: 排除不需要更新的字段列表
         :return: 更新成功返回主键ID，否则返回空字符串
         :last_editors: ChenXiaolei
         """
@@ -353,12 +461,25 @@ class BaseModel:
             field_list = self.model_obj.get_field_list()
         elif type(field_list) == str:
             field_list = field_list.split(",")
+
+        exclude_field = None
+
+        if exclude_field_list and type(exclude_field_list) == list:
+            exclude_field = exclude_field_list
+        elif exclude_field_list and type(exclude_field_list) == str:
+            exclude_field = exclude_field_list.split(",")
+
+        if exclude_field:
+            for exclude_field in exclude_field_list:
+                if exclude_field in field_list:
+                    field_list.remove(exclude_field)
+
         if len(field_list) == 0:
             return 0
         update_field_str = ""
 
         param = []
-        mid = getattr(model,self.primary_key_field)
+        mid = getattr(model, self.primary_key_field)
         for field_str in field_list:
             if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
                 continue
@@ -386,7 +507,7 @@ class BaseModel:
             else:
                 return ""
 
-    def update_list(self, model_list, field_list=None, transaction=False):
+    def update_list(self, model_list, field_list=None, exclude_field_list=None, transaction=False):
         """
         :Description: 根据模型的主键ID，更新字段的值
         :param model: 模型实体
@@ -400,13 +521,26 @@ class BaseModel:
             field_list = self.model_obj.get_field_list()
         elif type(field_list) == str:
             field_list = field_list.split(",")
+
+        exclude_field = None
+
+        if exclude_field_list and type(exclude_field_list) == list:
+            exclude_field = exclude_field_list
+        elif exclude_field_list and type(exclude_field_list) == str:
+            exclude_field = exclude_field_list.split(",")
+
+        if exclude_field:
+            for exclude_field in exclude_field_list:
+                if exclude_field in field_list:
+                    field_list.remove(exclude_field)
+
         if len(field_list) == 0:
             return 0
         for model in model_list:
             update_field_str = ""
 
             param = []
-            mid = getattr(model,self.primary_key_field)
+            mid = getattr(model, self.primary_key_field)
             for field_str in field_list:
                 if self.primary_key_field and str(field_str).lower() == self.primary_key_field.lower():
                     continue
@@ -427,9 +561,12 @@ class BaseModel:
                 transaction_item["params"] = tuple(param)
                 self.db_transaction.transaction_list.append(transaction_item)
             elif transaction:
-                sql_list.append(sql)
+                transaction_item = {}
+                transaction_item["sql"] = sql
+                transaction_item["params"] = tuple(param)
+                sql_list.append(transaction_item)
             else:
-                data = self.db.update(sql, tuple(param))
+                self.db.update(sql, tuple(param))
         if transaction and not self.is_transaction():
             if not self.transaction_execute(sql_list):
                 return False
@@ -478,8 +615,8 @@ class BaseModel:
             group_by = " GROUP BY "+group_by
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
-        if limit and limit.strip() != '':
-            limit = " LIMIT "+limit
+        if limit:
+            limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit}"
         one_row = self.db.fetch_one_row(sql, params)
         return one_row  # self.__row_entity(list_row)
@@ -514,10 +651,14 @@ class BaseModel:
             group_by = " GROUP BY "+group_by
         if order_by and order_by.strip() != '':
             order_by = " ORDER BY " + order_by
-        if limit and limit.strip() != '':
-            limit = " LIMIT "+limit
+        if limit:
+            limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
         list_row = self.db.fetch_all_rows(sql, params)
+
+        if not list_row:
+            list_row = []
+
         return list_row
 
     def get_dict_page_list(self,
@@ -550,7 +691,13 @@ class BaseModel:
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {str(int(page_index) * int(page_size))},{str(page_size)}"
         list_row = self.db.fetch_all_rows(sql, params)
 
-        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
+        if not list_row:
+            list_row = []
+
+        sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by}"
+
+        if group_by:
+            sql = f"SELECT COUNT(*) as count FROM ({sql}) temp_table"
         row = self.db.fetch_one_row(sql, params)
 
         if row and 'count' in row and int(row['count']) > 0:
