@@ -3,7 +3,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-11-04 10:37:38
-:LastEditTime: 2020-12-25 10:50:02
+:LastEditTime: 2021-09-16 12:12:56
 :LastEditors: ChenXiaolei
 :Description: csv helper
 """
@@ -529,7 +529,7 @@ class CSVHelper:
                 for row in self.__data_list:
                     str_write = ''
                     for data in row:
-                        str_write += data
+                        str_write += str(data)
                         str_write += ','
                     str_write = str_write[0:len(str_write) - 1]
                     str_write += '\n'
