@@ -2,13 +2,14 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-05-19 10:33:52
-:LastEditTime: 2021-01-04 19:29:29
+:LastEditTime: 2021-05-21 15:55:39
 :LastEditors: ChenXiaolei
 :Description: ufile传输
 """
 from abc import get_cache_token
 from ufile.filemanager import *
 import traceback
+import multiprocessing
 
 
 class UFileHelper(FileManager):
@@ -902,7 +903,7 @@ class COSHelper():
 
     def put_file_from_file_path(self, bucket_name, object_name, local_file):
         """
-        :description: 
+        :description: 通过文件路径上传文件
         :param bucket_name: bucket名称
         :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
         :param local_file: 表示本地文件的完整路径，例如/users/local/abc.jpg。
@@ -916,7 +917,7 @@ class COSHelper():
 
     def put_file(self, bucket_name, object_name, source_file_object):
         """
-        :description: 
+        :description: 上传文件
         :param bucket_name: bucket名称
         :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
         :param source_file_object: 上传文件对象
@@ -996,4 +997,281 @@ class COSHelper():
         except:
             raise
 
-        return objects, dirs
\ No newline at end of file
+        return objects, dirs
+
+
+class BOSHelper():
+    """
+    :description: 百度云存储
+    :last_editors: ChenXiaolei
+    """
+    BOS_HOST = ""
+    ACCESS_KEY_ID = ""
+    SECRET_ACCESS_KEY = ""
+
+    def __init__(self, access_key_id, secret_access_key, bos_host, **other_config):
+        """
+        :description: 百度云存储(BOS)初始化
+        :param access_key_id: 百度云后台密钥id
+        :param secret_access_key: 百度云后台密钥key
+        :param bos_host: 指定百度云存储节点host
+        :last_editors: ChenXiaolei
+        """
+        from baidubce.bce_client_configuration import BceClientConfiguration
+        from baidubce.auth.bce_credentials import BceCredentials
+        from baidubce import exception
+        from baidubce.services import bos
+        from baidubce.services.bos import canned_acl
+        from baidubce.services.bos.bos_client import BosClient
+
+        # 创建BceClientConfiguration
+        self.bos_config = BceClientConfiguration(credentials=BceCredentials(
+            access_key_id, secret_access_key), endpoint=bos_host, **other_config)
+        # 创建BOS客户端
+        self.bos_client = BosClient(self.bos_config)
+
+    def get_file_info(self, bucket_name, object_name):
+        """
+        :description: 获取对象信息
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :return 成功返回对象信息 失败则抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            return self.bos_client.get_object_meta_data(bucket_name=bucket_name, key=object_name)
+        except:
+            raise
+
+    def get_object(self, bucket_name, object_name):
+        """
+        :description: 获取对象数据流
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :return 对象数据流
+        :last_editors: ChenXiaolei
+        """
+        try:
+            return self.bos_client.get_object(bucket_name, object_name)
+        except:
+            raise
+
+    def save_file(self, bucket_name, object_name, local_file):
+        """
+        :description: 将指定的OSS文件下载到本地文件
+        :param bucket_name: bucket名称
+        :param object_name: 表示下载的OSS文件的完整名称，即包含文件后缀在内的完整路径，例如abc/efg/123.jpg
+        :param local_file: 由本地文件路径加文件名包括后缀组成，例如/users/local/myfile.txt。
+        :return HTTP Response
+        :last_editors: ChenXiaolei
+        """
+
+        try:
+            return self.bos_client.get_object_to_file(bucket_name, object_name, local_file)
+        except:
+            raise
+
+    def put_file_from_file_path(self, bucket_name, object_name, local_file):
+        """
+        :description: 通过文件路径上传文件
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param local_file: 表示本地文件的完整路径，例如/users/local/abc.jpg。
+        :return 成功 True 异常抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.bos_client.put_object_from_file(
+                bucket_name, object_name, local_file)
+
+            return True
+        except:
+            raise
+
+    def put_file(self, bucket_name, object_name, source_file_object):
+        """
+        :description: 
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param source_file_object: 上传文件对象
+        :return 成功 True 其他异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.bos_client.put_object_from_string(
+                bucket_name, object_name, source_file_object)
+
+            return True
+        except:
+            raise
+
+    def put_file_stream(self, bucket_name, object_name, data, content_length, content_md5):
+        """
+        :description: 以数据流形式上传Object
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param data: file stream
+        :param content_length: 对象MD5值,计算方法是对数据执行md5算法获取128位二进制数据
+        :param content_md5: 对象MD5值
+        :return 成功 True 其他异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.bos_client.put_object(
+                bucket_name, object_name, data, content_length, content_md5)
+
+            return True
+        except:
+            raise
+
+    def del_file(
+        self,
+        bucket_name,
+        object_name,
+    ):
+        """
+        :Description: 删除文件
+        :param bucket_name: bucket名称
+        :param key_name: 存储对象名称
+        :return 成功True 失败抛出异常
+        :last_editors: ChenXiaolei
+        """
+        try:
+            self.bos_client.delete_object(bucket_name, object_name)
+            return True
+        except:
+            raise
+
+    def multi_put_file(self, bucket_name, object_name, local_file, chunk_size=5, thread_num=multiprocessing.cpu_count()):
+        """
+        :description: 分片上传,自动计算分片
+        :param bucket_name: bucket名称
+        :param object_name: 表示不包含Bucket名称在内的Object的完整路径，例如example/folder/abc.jpg。
+        :param local_file: 表示本地文件的完整路径，例如/users/local/abc.jpg。
+        :return 成功True 失败抛出异常
+        :last_editors: ChenXiaolei
+        """
+
+        try:
+            self.bos_client.put_super_obejct_from_file(
+                bucket_name, object_name, local_file, chunk_size=chunk_size, thread_num=thread_num)
+        except:
+            raise
+
+        return True
+
+    def get_bucket_objects(self, bucket_name, prefix="", delimiter=""):
+        """
+        :description: 列举bucket下的文件和文件夹信息
+        :param bucket_name: bucket名称
+        :param prefix: bucket目录 例如"fun/"
+        :param delimiter: 对文件名称进行分组的字符 例如"/"
+        :return 文件列表，目录列表
+        :last_editors: ChenXiaolei
+        """
+
+        objects = []
+        dirs = []
+
+        try:
+            object_list = self.bos_client.list_objects(bucket_name,
+                                                       prefix=prefix,
+                                                       delimiter=delimiter)
+
+            if not object_list or not hasattr(object_list,"contents") or len(
+                    object_list.contents) == 0:
+                return objects, dirs
+            for obj in object_list.contents:
+                if obj.key.find('/') > -1 and obj.key.split(
+                        '/')[::2] not in dirs:
+                    dirs.append(obj.key.split('/')[::2])
+
+                objects.append(obj)
+        except:
+            raise
+
+        return objects, dirs
+
+
+class LocalFileHelper():
+    """
+    :description: 本地文件读写操作
+    :last_editors: ChenXiaolei
+    """
+    @classmethod
+    def get_file_content(self, file_path):
+        """
+        :description: 获取文件内容
+        :param path:文件路径
+        :return 文件内容
+        :last_editors: ChenXiaolei
+        """
+        if not file_path or not self.check_file_exists(file_path):
+            return ""
+        with open(file_path) as file_object:
+            file_content = file_object.read()
+            return file_content
+
+    @classmethod
+    def get_file_content_array(self, file_path):
+        """
+        :description: 获取文件内容,按行构造为数组
+        :param file_path: 文件路径
+        :return 文件内容按行转换后的数组
+        :last_editors: ChenXiaolei
+        """
+        if not file_path:
+            return None
+        file_content = self.get_file_content(file_path)
+
+        return self._content_array(file_content)
+
+    @classmethod
+    def _content_to_array(self, file_content):
+        """
+        :description: 将文件内容按行转为数组
+        :param file_content:文件内容
+        :return 文件内容按行转换后的数组
+        :last_editors: ChenXiaolei
+        """
+        contents_arr_new = []
+
+        contents_arr = str(file_content).split(']')
+
+        for i in range(len(contents_arr)):
+
+            if (contents_arr[i].__contains__('[')):
+                index = contents_arr[i].rfind('[')
+                temp_str = contents_arr[i][index + 1:]
+
+                if temp_str.__contains__('"'):
+
+                    contents_arr_new.append(temp_str.replace('"', ''))
+
+        return contents_arr_new
+
+    @classmethod
+    def write_file(self, file_path, content, mode="w", encoding='utf8'):
+        """
+        :description: 文件写入
+        :param file_path: 文件路径
+        :param content: 写入内容
+        :return {*}
+        :last_editors: ChenXiaolei
+        """
+        # 打开文件
+        file = open(file_path, mode, encoding=encoding)
+        # 写入文件内容
+        file.write(content)
+        # 关闭文件
+        file.close()
+
+    @classmethod
+    def check_file_exists(self, file_path):
+        """
+        :description: 判断文件是否存在
+        :param file_path: 文件路径
+        :return 存在则返回True 不存在返回False
+        :last_editors: ChenXiaolei
+        """
+        return os.path.exists(file_path)
