@@ -29,12 +29,10 @@ class MySQLHelper(object):
             maxconnections=0,  # 连接池允许的最大连接数，0和None表示不限制连接数
             mincached=0,  # 初始化时，链接池中至少创建的空闲的链接，0表示不创建
             maxcached=0,  # 链接池中最多闲置的链接，0和None不限制
-            maxshared=
-            0,  # 链接池中最多共享的链接数量，0和None表示全部共享。PS: 无用，因为pymysql和MySQLdb等模块的 threadsafety都为1，所有值无论设置为多少，_maxcached永远为0，所以永远是所有链接都共享。
+            maxshared=0,  # 链接池中最多共享的链接数量，0和None表示全部共享。PS: 无用，因为pymysql和MySQLdb等模块的 threadsafety都为1，所有值无论设置为多少，_maxcached永远为0，所以永远是所有链接都共享。
             blocking=True,  # 连接池中如果没有可用连接后，是否阻塞等待。True，等待；False，不等待然后报错
             maxusage=None,  # 一个链接最多被重复使用的次数，None表示无限制
-            setsession=
-            [],  # 开始会话前执行的命令列表。如：["set datestyle to ...", "set time zone ..."]
+            setsession=[],  # 开始会话前执行的命令列表。如：["set datestyle to ...", "set time zone ..."]
             ping=0,
             # ping MySQL服务端，检查是否服务可用。# 如：0 = None = never, 1 = default = whenever it is requested, 2 = when a cursor is created, 4 = when a query is executed, 7 = always
             host=dbconfig['host'],
@@ -45,7 +43,7 @@ class MySQLHelper(object):
             charset=dbconfig['charset'])
 
         try:
-            if not hasattr(self,"context") or self.context:
+            if not hasattr(self, "context") or not self.context:
                 self._log_sql = log.Logger.get_logger_by_name("log_sql")
         except:
             pass
@@ -68,7 +66,7 @@ class MySQLHelper(object):
             # 如果有handler上下文,则使用链路日志记录
             if hasattr(self, "context") and self.context:
                 self.context.logging_link_sql(log_msg)
-            else:
+            elif hasattr(self, "_log_sql") and self._log_sql:
                 self._log_sql.info(log_msg)
         except:
             print(traceback.print_exc())
@@ -119,20 +117,25 @@ class MySQLHelper(object):
         self._add_sql_log(row_count)
         return row_count
 
-    def insert(self, sql, params=None):
+    def insert(self, sql, params=None, return_increment_primary=True):
         """
         :Description: 执行 INSERT 语句
         :param sql: 数据insert语句
+        :param return_increment_id: true=返回自增ID false=返回影响行数
         :return: 如主键为自增长int，则返回新生成的ID
         :last_editors: ChenXiaolei
         """
         # 执行 INSERT 语句。如主键为自增长int，则返回新生成的ID
         self._execute(sql, params)
         self._conn.commit()
-        primary_id = self._cur._result.insert_id
+        result = 0
+        if return_increment_primary:
+            result = self._cur._result.insert_id
+        else:
+            result = self._cur._result.affected_rows
         self.close()
-        self._add_sql_log(primary_id)
-        return primary_id
+        self._add_sql_log(result)
+        return result
 
     def _execute(self, sql, params=None):
         try:
@@ -162,10 +165,11 @@ class MySQLHelper(object):
             raise Exception("mysql execute error:" + str(e) + " sql:" +
                             str(sql) + " 参数:" + str(params))
 
-    def transaction_execute(self, sql_list):
+    def transaction_execute(self, sql_list, return_detail_tuple=False):
         """
         :Description: 事务提交
         :param sql_list: sql字符串数组
+        :param return_detail_tuple: 返回详细的元组信息
         :return: 执行成功返回 True   失败 False
         :last_editors: ChenXiaolei
         """
@@ -184,11 +188,15 @@ class MySQLHelper(object):
             print(e)
             self._conn.rollback  # 事务回滚
             # raise Exception("执行事务ERROR:" + str(e) + " SQL：" + str(sql))
+            if return_detail_tuple:
+                return (False, f"MYSQL事务执行失败并进行回滚,执行SQL:{sql},异常:{traceback.format_exc()}")
             return False
         else:
             self._conn.commit()  # 事务提交
             self._cur.close()
             self._conn.close()
+        if return_detail_tuple:
+            return (True, "")
         return True
 
     def fetch_all_rows(self, sql, params=None):
@@ -328,6 +336,7 @@ class DbTransaction(object):
     :Description: 数据库事务执行类
     :last_editors: ChenXiaolei
     """
+
     def __init__(self, db_config_dict=None, db=None):
         self.transaction_list = []
         self.is_transaction = False
@@ -349,9 +358,10 @@ class DbTransaction(object):
         self.is_transaction = True
         return True
 
-    def commit_transaction(self):
+    def commit_transaction(self, return_detail_tuple=False):
         """
         :Description: 提交事务
+        :param return_detail_tuple: 返回详细的元组信息 True=tuple(Ture/False,str(异常信息,正常为空字符串))
         :return: 成功True  失败False
         :last_editors: ChenXiaolei
         """
@@ -363,7 +373,7 @@ class DbTransaction(object):
         self.is_transaction = False
         delattr(self, "transaction_list")
 
-        return self.db.transaction_execute(sql_list)
+        return self.db.transaction_execute(sql_list, return_detail_tuple)
 
     def rollback_transaction(self):
         """
