@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: YuMinJie
-@Date: 2020-05-15 11:16:28
-@LastEditTime: 2020-06-10 14:04:27
-@LastEditors: ChenXiaolei
-@Description: 消息帮助类
+:Author: YuMinJie
+:Date: 2020-05-15 11:16:28
+:LastEditTime: 2020-06-10 14:04:27
+:LastEditors: ChenXiaolei
+:Description: 消息帮助类
 """
 
 
@@ -16,7 +16,7 @@ import os
 class NoticeHelper(object):
 
     """
-    @description: 企业微信群机器人消息
+    :Description: 企业微信群机器人消息
     """
 
     def __init__(self, webhook_key='', project_name=None):
@@ -36,9 +36,9 @@ class NoticeHelper(object):
 
     def _get_webhook_key(self, webhook_key=''):
         """
-        @description: 获取webhook_key，判断传参webhook_key是否为空字符串，如果为空字符串则从初始化属性获取
-        @param webhook_key: webhook密钥，默认值为空字符串
-        @return: webhook_key
+        :Description: 获取webhook_key，判断传参webhook_key是否为空字符串，如果为空字符串则从初始化属性获取
+        :param webhook_key: webhook密钥，默认值为空字符串
+        :return: webhook_key
 
         """
         if not webhook_key or webhook_key == '':
@@ -49,12 +49,12 @@ class NoticeHelper(object):
 
     def send_webhook(self, text='', mentioned_list=[], mentioned_mobile_list=[], webhook_key=''):
         """
-        @description: 发送企业微信消息
-        @param webhook_key: webhook秘钥
-        @param text:消息文本
-        @param mentioned_list:工号、企业微信名或者@all
-        @param mentioned_mobile_list:传入手机号或者@all
-        @return: 企业微信消息
+        :Description: 发送企业微信消息
+        :param webhook_key: webhook秘钥
+        :param text:消息文本
+        :param mentioned_list:工号、企业微信名或者@all
+        :param mentioned_mobile_list:传入手机号或者@all
+        :return: 企业微信消息
 
         """
 
