@@ -13,7 +13,7 @@ from redis import RedisError
 
 class RedisHelper:
     @classmethod
-    def redis_init(self, host="", port=0, db=0, password=None, config_dict=None):
+    def redis_init(self, host="", port=0, db=0, password=None, config_dict=None, decode_responses=False):
         """
         :Description: 从redis连接池中创建对象
         :param host:主机地址
@@ -41,6 +41,6 @@ class RedisHelper:
         pool = redis.ConnectionPool(host=host,
                                     port=port,
                                     db=db,
-                                    password=password)
-        redis_client = redis.Redis(connection_pool=pool, decode_responses=True)
+                                    password=password, decode_responses=decode_responses)
+        redis_client = redis.Redis(connection_pool=pool)
         return redis_client
