@@ -1,10 +1,9 @@
 '''
-@Author: ChenXiaolei
-@Date: 2020-03-06 23:17:54
-@LastEditTime: 2020-03-21 16:50:31
-@LastEditors: ChenXiaolei
-@Description: time helper
-@FilePath: /python_base_framework/libs./seven_framework/time.py
+:Author: ChenXiaolei
+:Date: 2020-03-06 23:17:54
+:LastEditTime: 2020-03-21 16:50:31
+:LastEditors: ChenXiaolei
+:Description: time helper
 '''
 # -*- coding: utf-8 -*-
 
@@ -19,24 +18,43 @@ class TimeHelper:
                                 format_time=None,
                                 format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 时间字符串转datetime
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 时间字符串转datetime
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         if not format_time:
             return datetime.datetime.now()
         return datetime.datetime.strptime(format_time, format)
 
+    @classmethod
+    def format_time_convert_format(self,
+                                   format_time=None,
+                                   format_before='%Y-%m-%d %H:%M:%S',
+                                   format_after='%Y-%m-%d %H:%M:%S'):
+        """
+        :Description: 转换格式时间的格式
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param format_before: 格式化之前的时间格式
+        :param format_after: 希望转换格式化后的时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
+        """
+        if not format_time:
+            return self.get_now_format_time(format=format_after)
+        return self.datetime_to_format_time(self.format_time_to_datetime(
+            format_time, format_before),
+                                            format=format_after)
+
     @classmethod
     def datetime_to_format_time(self, dt, format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: datetime转时间字符串
-        @param dt: datetime格式时间
-        @param format: 格式化时间格式
-        @return: 时间字符串
-        @last_editors: ChenXiaolei
+        :Description: datetime转时间字符串
+        :param dt: datetime格式时间
+        :param format: 格式化时间格式
+        :return: 时间字符串
+        :last_editors: ChenXiaolei
         """
         return dt.strftime(format)
 
@@ -46,11 +64,11 @@ class TimeHelper:
                               format='%Y-%m-%d %H:%M:%S',
                               out_ms=False):
         """
-        @description: datetime转unix时间戳
-        @param dt: datetime格式时间
-        @param format: 格式化时间格式
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: datetime转unix时间戳
+        :param dt: datetime格式时间
+        :param format: 格式化时间格式
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         if out_ms:
             return int(
@@ -62,11 +80,11 @@ class TimeHelper:
                                  format_time=None,
                                  format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 格式化时间转为Unix时间戳
-        @param format_time: 格式化时间，如果未传则返回服务器当前时间
-        @param format: 格式化时间格式
-        @return: Unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 格式化时间转为Unix时间戳
+        :param format_time: 格式化时间，如果未传则返回服务器当前时间
+        :param format: 格式化时间格式
+        :return: Unix时间戳
+        :last_editors: ChenXiaolei
         """
         if format_time:
             time_tuple = time.strptime(format_time, format)
@@ -79,11 +97,11 @@ class TimeHelper:
                                  timestamp=None,
                                  format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 时间戳转格式化时间
-        @param timestamp: unix时间戳
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 时间戳转格式化时间
+        :param timestamp: unix时间戳
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         if timestamp:
             time_tuple = time.localtime(timestamp)
@@ -95,10 +113,10 @@ class TimeHelper:
     @classmethod
     def timestamp_to_datetime(self, timestamp=time.time()):
         """
-        @description: unix时间戳转datetime
-        @param timestamp: unix时间戳，如果没传默认取服务器当前时间
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: unix时间戳转datetime
+        :param timestamp: unix时间戳，如果没传默认取服务器当前时间
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         if self.is_ms_timestamp(timestamp):
             timestamp = timestamp / 1000
@@ -109,12 +127,12 @@ class TimeHelper:
                            in_format='%Y-%m-%d %H:%M:%S',
                            out_format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 更改格式化时间格式
-        @param in_format_time: 更改前格式化时间字符串
-        @param in_format: 更改前格式化时间格式
-        @param out_format: 需更改的格式化时间格式
-        @return: 格式化时间字符串
-        @last_editors: ChenXiaolei
+        :Description: 更改格式化时间格式
+        :param in_format_time: 更改前格式化时间字符串
+        :param in_format: 更改前格式化时间格式
+        :param out_format: 需更改的格式化时间格式
+        :return: 格式化时间字符串
+        :last_editors: ChenXiaolei
         """
         return self.timestamp_to_format_time(
             self.format_time_to_timestamp(in_format_time, in_format),
@@ -123,10 +141,10 @@ class TimeHelper:
     @classmethod
     def get_now_timestamp(self, is_ms=False):
         """
-        @description: 获取当前时间戳
-        @param is_ms: 是否输出毫秒级时间戳 是-True 否-False
-        @return: 时间戳
-        @last_editors: ChenXiaolei
+        :Description: 获取当前时间戳
+        :param is_ms: 是否输出毫秒级时间戳 是-True 否-False
+        :return: 时间戳
+        :last_editors: ChenXiaolei
         """
         if is_ms:
             return int(round(time.time() * 1000))
@@ -136,29 +154,29 @@ class TimeHelper:
     @classmethod
     def get_now_datetime(self):
         """
-        @description: 获取当前时间格式
-        @return: 格式化时间
-        @last_editors: ChenXiaolei
+        :Description: 获取当前时间格式
+        :return: 格式化时间
+        :last_editors: ChenXiaolei
         """
         return datetime.datetime.now()
 
     @classmethod
     def get_now_format_time(self, format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 获取当前时间格式
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 获取当前时间格式
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return datetime.datetime.now().strftime(format)
 
     @classmethod
     def is_ms_timestamp(self, timestamp):
         """
-        @description: 时间戳是否为毫秒时间戳
-        @param timestamp: unix时间戳
-        @return: bool
-        @last_editors: ChenXiaolei
+        :Description: 时间戳是否为毫秒时间戳
+        :param timestamp: unix时间戳
+        :return: bool
+        :last_editors: ChenXiaolei
         """
         if timestamp and len(str(int(timestamp))) > 10:
             return True
@@ -168,11 +186,11 @@ class TimeHelper:
     @classmethod
     def add_seconds_by_timestamp(self, timestamp=None, second=1):
         """
-        @description: 为时间戳增加秒数
-        @param timestamp: unix时间戳
-        @param second: 秒数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加秒数
+        :param timestamp: unix时间戳
+        :param second: 秒数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         if not timestamp:
             timestamp = self.get_now_timestamp()
@@ -186,44 +204,44 @@ class TimeHelper:
     @classmethod
     def add_minutes_by_timestamp(self, timestamp=None, minute=1):
         """
-        @description: 为时间戳增加分钟数
-        @param timestamp: unix时间戳
-        @param minute: 分钟数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加分钟数
+        :param timestamp: unix时间戳
+        :param minute: 分钟数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         return self.add_seconds_by_timestamp(timestamp, minute * 60)
 
     @classmethod
     def add_hours_by_timestamp(self, timestamp=None, hour=1):
         """
-        @description: 为时间戳增加小时数
-        @param timestamp: unix时间戳
-        @param hour: 小时数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加小时数
+        :param timestamp: unix时间戳
+        :param hour: 小时数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         return self.add_seconds_by_timestamp(timestamp, hour * 3600)
 
     @classmethod
     def add_days_by_timestamp(self, timestamp=None, day=1):
         """
-        @description: 为时间戳增加天数
-        @param timestamp: unix时间戳
-        @param day: 天数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加天数
+        :param timestamp: unix时间戳
+        :param day: 天数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         return self.add_seconds_by_timestamp(timestamp, day * 86400)
 
     @classmethod
     def add_months_by_timestamp(self, timestamp=None, months=1):
         """
-        @description: 为时间戳增加月数
-        @param timestamp: unix时间戳
-        @param months: 月数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加月数
+        :param timestamp: unix时间戳
+        :param months: 月数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         if not timestamp:
             timestamp = time.time()
@@ -236,11 +254,11 @@ class TimeHelper:
     @classmethod
     def add_years_by_timestamp(self, timestamp=None, years=1):
         """
-        @description: 为时间戳增加年数
-        @param timestamp: unix时间戳
-        @param years: 年数
-        @return: unix时间戳
-        @last_editors: ChenXiaolei
+        :Description: 为时间戳增加年数
+        :param timestamp: unix时间戳
+        :param years: 年数
+        :return: unix时间戳
+        :last_editors: ChenXiaolei
         """
         if not timestamp:
             timestamp = time.time()
@@ -256,11 +274,11 @@ class TimeHelper:
                                   second=1,
                                   format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加秒数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param second: 秒数
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加秒数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param second: 秒数
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 datetime.timedelta(seconds=second)).strftime(format)
@@ -271,12 +289,12 @@ class TimeHelper:
                                    minute=1,
                                    format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加分钟数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param minute: 分钟数
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加分钟数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param minute: 分钟数
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 datetime.timedelta(minutes=minute)).strftime(format)
@@ -287,12 +305,12 @@ class TimeHelper:
                                  hour=1,
                                  format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加小时数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param hour: 小时数
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加小时数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param hour: 小时数
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 datetime.timedelta(hours=hour)).strftime(format)
@@ -303,12 +321,12 @@ class TimeHelper:
                                 day=1,
                                 format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加分钟数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param day: 天数
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加天数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param day: 天数
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 datetime.timedelta(days=day)).strftime(format)
@@ -319,12 +337,12 @@ class TimeHelper:
                                   months=1,
                                   format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加月数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param months: 月数
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加月数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param months: 月数
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 relativedelta(months=months)).strftime(format)
@@ -335,12 +353,12 @@ class TimeHelper:
                                  years=1,
                                  format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 为时间格式增加年数
-        @param format_time: 格式化时间，如果未传则取服务器当前时间
-        @param years: 年数
-        @param format: 格式化时间格式
-        @return: datetime
-        @last_editors: ChenXiaolei
+        :Description: 为时间格式增加年数
+        :param format_time: 格式化时间，如果未传则取服务器当前时间
+        :param years: 年数
+        :param format: 格式化时间格式
+        :return: datetime
+        :last_editors: ChenXiaolei
         """
         return (self.format_time_to_datetime(format_time, format) +
                 relativedelta(years=years)).strftime(format)
@@ -351,11 +369,11 @@ class TimeHelper:
                             subtracter_time,
                             format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 计算两个时间的差值,支持datetime/timstamp/format_time
-        @param minuend_time: 被减时间
-        @param subtracter_time: 减时间
-        @return 时间差值(datetime)
-        @last_editors: ChenXiaolei
+        :Description: 计算两个时间的差值,支持datetime/timstamp/format_time
+        :param minuend_time: 被减时间
+        :param subtracter_time: 减时间
+        :return 时间差值(datetime)
+        :last_editors: ChenXiaolei
         """
         if type(minuend_time) == datetime.datetime:
             minuend = minuend_time
@@ -383,11 +401,11 @@ class TimeHelper:
                         subtracter_time,
                         format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 计算两个时间的差值天数,支持datetime/timstamp/format_time
-        @param minuend_time: 被减时间
-        @param subtracter_time: 减时间
-        @return 天数(int)
-        @last_editors: ChenXiaolei
+        :Description: 计算两个时间的差值天数,支持datetime/timstamp/format_time
+        :param minuend_time: 被减时间
+        :param subtracter_time: 减时间
+        :return 天数(int)
+        :last_editors: ChenXiaolei
         """
         return self.difference_datetime(minuend_time,
                                         subtracter_time,
@@ -399,11 +417,11 @@ class TimeHelper:
                            subtracter_time,
                            format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 计算两个时间的差值秒数,支持datetime/timstamp/format_time
-        @param minuend_time: 被减时间
-        @param subtracter_time: 减时间
-        @return 秒数(int)
-        @last_editors: ChenXiaolei
+        :Description: 计算两个时间的差值秒数,支持datetime/timstamp/format_time
+        :param minuend_time: 被减时间
+        :param subtracter_time: 减时间
+        :return 秒数(int)
+        :last_editors: ChenXiaolei
         """
         return int(
             self.difference_datetime(
@@ -416,11 +434,11 @@ class TimeHelper:
                            subtracter_time,
                            format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 计算两个时间的差值分钟数,支持datetime/timstamp/format_time
-        @param minuend_time: 被减时间
-        @param subtracter_time: 减时间
-        @return 分钟数(int)
-        @last_editors: ChenXiaolei
+        :Description: 计算两个时间的差值分钟数,支持datetime/timstamp/format_time
+        :param minuend_time: 被减时间
+        :param subtracter_time: 减时间
+        :return 分钟数(int)
+        :last_editors: ChenXiaolei
         """
         return int(
             self.difference_seconds(
@@ -433,11 +451,11 @@ class TimeHelper:
                          subtracter_time,
                          format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 计算两个时间的差值小时数,支持datetime/timstamp/format_time
-        @param minuend_time: 被减时间
-        @param subtracter_time: 减时间
-        @return 小时数(int)
-        @last_editors: ChenXiaolei
+        :Description: 计算两个时间的差值小时数,支持datetime/timstamp/format_time
+        :param minuend_time: 被减时间
+        :param subtracter_time: 减时间
+        :return 小时数(int)
+        :last_editors: ChenXiaolei
         """
         return int(
             self.difference_seconds(
@@ -447,10 +465,10 @@ class TimeHelper:
     @classmethod
     def get_first_day_of_the_week(self):
         """
-        @description: 获取本周一的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本周一的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return (now_datetime -
@@ -459,10 +477,10 @@ class TimeHelper:
     @classmethod
     def get_last_day_of_the_week(self):
         """
-        @description: 获取本周日的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本周日的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return (now_datetime +
@@ -471,10 +489,10 @@ class TimeHelper:
     @classmethod
     def is_this_week(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 指定时间是否在本周内
-        @param date: 时间类型,支持timestamp/datetime/format_time
-        @return 指定时间在本周内=True 指定时间不在本周内=False
-        @last_editors: ChenXiaolei
+        :Description: 指定时间是否在本周内
+        :param date: 时间类型,支持timestamp/datetime/format_time
+        :return 指定时间在本周内=True 指定时间不在本周内=False
+        :last_editors: ChenXiaolei
         """
         compare_datetime = date
         if type(date) == int:
@@ -489,10 +507,10 @@ class TimeHelper:
     @classmethod
     def get_first_day_of_the_month(self):
         """
-        @description: 获取本月第一天的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本月第一天的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year, now_datetime.month, 1)
@@ -500,10 +518,10 @@ class TimeHelper:
     @classmethod
     def get_last_day_of_the_month(self):
         """
-        @description: 获取本月最后一天的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本月最后一天的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year, now_datetime.month + 1,
@@ -512,10 +530,10 @@ class TimeHelper:
     @classmethod
     def is_this_month(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 指定时间是否在本周内
-        @param date: 时间类型,支持timestamp/datetime/format_time
-        @return 指定时间在本周内=True 指定时间不在本周内=False
-        @last_editors: ChenXiaolei
+        :Description: 指定时间是否在本周内
+        :param date: 时间类型,支持timestamp/datetime/format_time
+        :return 指定时间在本周内=True 指定时间不在本周内=False
+        :last_editors: ChenXiaolei
         """
         compare_datetime = date
         if type(date) == int:
@@ -530,10 +548,10 @@ class TimeHelper:
     @classmethod
     def get_first_day_of_the_year(self):
         """
-        @description: 获取本年第一天的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本年第一天的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year, 1, 1)
@@ -541,10 +559,10 @@ class TimeHelper:
     @classmethod
     def get_last_day_of_the_year(self):
         """
-        @description: 获取本年最后一天的日期
-        @param 无
-        @return datetime.date
-        @last_editors: ChenXiaolei
+        :Description: 获取本年最后一天的日期
+        :param 无
+        :return datetime.date
+        :last_editors: ChenXiaolei
         """
         now_datetime = self.get_now_datetime()
         return datetime.datetime(now_datetime.year + 1, 1,
@@ -553,10 +571,10 @@ class TimeHelper:
     @classmethod
     def is_this_year(self, date, format='%Y-%m-%d %H:%M:%S'):
         """
-        @description: 指定时间是否在本年内
-        @param date: 时间类型,支持timestamp/datetime/format_time
-        @return 指定时间在本周内=True 指定时间不在本周内=False
-        @last_editors: ChenXiaolei
+        :Description: 指定时间是否在本年内
+        :param date: 时间类型,支持timestamp/datetime/format_time
+        :return 指定时间在本周内=True 指定时间不在本周内=False
+        :last_editors: ChenXiaolei
         """
         compare_datetime = date
         if type(date) == int:
