@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-@Author: ChenXiaolei
-@Date: 2020-04-25 21:58:58
-@LastEditTime: 2020-04-28 09:46:50
-@LastEditors: ChenXiaolei
-@Description: 
+:Author: ChenXiaolei
+:Date: 2020-04-25 21:58:58
+:LastEditTime: 2020-04-28 09:46:50
+:LastEditors: ChenXiaolei
+:Description: 
 """
 
 # from . import base_api_handler
