@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2020-05-27 16:30:11
+:LastEditTime: 2021-06-24 17:00:16
 :LastEditors: ChenXiaolei
 :Description: Handler基础类(api)
 """
@@ -16,7 +16,6 @@ class BaseApiHandler(BaseHandler):
     :Description: api base handler. not session
     :last_editors: ChenXiaolei
     """
-
     def __init__(self, *argc, **argkw):
         """
         :Description: 初始化
@@ -29,7 +28,11 @@ class BaseApiHandler(BaseHandler):
         :Description: 重写全局异常事件捕捉
         :last_editors: ChenXiaolei
         """
-        self.logger_error.error(traceback.format_exc())
+        self.logger_error.error(
+            traceback.format_exc(),
+            extra={"extra": {
+                "request_code": self.request_code if hasattr(self,"request_code") else ""
+            }})
         return self.reponse_json_error()
 
     def prepare_ext(self):
