@@ -2,7 +2,7 @@
 """
 :Author: ChenXiaolei
 :Date: 2020-03-06 23:17:54
-:LastEditTime: 2021-03-16 17:17:42
+:LastEditTime: 2021-11-03 18:05:22
 :LastEditors: ChenXiaolei
 :Description: Handler基础类
 """
@@ -27,7 +27,8 @@ from seven_framework import *
 
 
 class BaseHandler(tornado.web.RequestHandler):
-    THREAD_POOL_COUNT = 500
+    # 最大线程池数量
+    THREAD_POOL_COUNT = config.get_value("thread_pool_count", 5000)
     """
     :Description: 基础handler
     :last_editors: ChenXiaolei
@@ -48,27 +49,27 @@ class BaseHandler(tornado.web.RequestHandler):
     # 异步重写
     async def get(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.get_async)
+                                                       self.get_async, *args)
 
     async def post(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.post_async)
+                                                       self.post_async, *args)
 
     async def delete(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.delete_async)
+                                                       self.delete_async, *args)
 
     async def put(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.put_async)
+                                                       self.put_async, *args)
 
     async def head(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.head_async)
+                                                       self.head_async, *args)
 
     async def options(self, *args, **kwargs):
         await asyncio.get_event_loop().run_in_executor(self.executor,
-                                                       self.options_async)
+                                                       self.options_async, *args)
 
     def prepare(self, *args, **argkw):
         """
@@ -87,7 +88,6 @@ class BaseHandler(tornado.web.RequestHandler):
 
     def _build_http_log(self, http_log_extra_dict=None):
         self.request_code = UUIDHelper.get_uuid()
-        print("---------request request_code:" + self.request_code)
         # 请求信息
         try:
             if "Content-Type" in self.request.headers and self.request.headers[
@@ -228,6 +228,19 @@ class BaseHandler(tornado.web.RequestHandler):
         return bleach.linkify(
             bleach.clean(htmlstr, tags=tags, attributes=attributes))
 
+    def response_file(self,file_name):
+        """
+        :description: 将文件流返回前端
+        :param file_name: 文件路径
+        :return 文件流
+        :last_editors: ChenXiaolei
+        """
+        _file_name = parse.quote(file_name)  # 对非ASCII进行编码防止中文乱码
+        self.set_header('Content-Type', 'application/octet-stream')
+        self.set_header('Content-Disposition', 'attachment;filename={}'.format(_file_name))
+        with open(file_name, 'rb') as f:
+            self.write(f.read())
+
     def write_error(self, status_code, **kwargs):
         """
         :Description: 重写全局异常事件捕捉
@@ -267,9 +280,9 @@ class BaseHandler(tornado.web.RequestHandler):
             ip_address = self.request.remote_ip
         return ip_address
 
-    def reponse_common(self, result, desc, data=None):
+    def reponse_common(self, result, desc, data=None, log_extra_dict=None):
         """
-        :Description: 输出公共json模型(过期)
+        :Description: 输出公共json模型
         :param result: 返回结果标识
         :param desc: 返回结果描述
         :param data: 返回结果对象，即为数组，字典
@@ -281,24 +294,29 @@ class BaseHandler(tornado.web.RequestHandler):
         template_value['desc'] = desc
         template_value['data'] = data
 
-        self.http_reponse(JsonHelper.json_dumps(template_value))
+        self.http_response(JsonHelper.json_dumps(template_value),
+                           log_extra_dict)
 
-    def http_reponse(self, content):
+    def http_reponse(self, content, log_extra_dict=None):
         """
-        :Description: 将字符串返回给客户端(过期)
+        :Description: 将字符串返回给客户端
         :param content: 内容字符串
         :return: 将字符串返回给客户端
         :last_editors: ChenXiaolei
         """
+        extra = {
+            "extra": {
+                "request_code": self.request_code,
+                "handler": self.__class__.__name__,
+                "action_mode": "output"
+            }
+        }
+
+        if log_extra_dict and type(log_extra_dict) == dict:
+            extra["extra"] = dict(extra["extra"], **log_extra_dict)
+
         content_log_info = f"http_output:{content}"
-        self.logger_http.info(content_log_info,
-                              extra={
-                                  "extra": {
-                                      "request_code": self.request_code,
-                                      "handler": self.__class__.__name__,
-                                      "action_mode": "output"
-                                  }
-                              })
+        self.logger_http.info(content_log_info, extra=extra)
         self.write(content)
 
     def reponse_json_success(self, data=None, desc='success'):
@@ -329,7 +347,7 @@ class BaseHandler(tornado.web.RequestHandler):
         """
         self.reponse_common(0, desc)
 
-    def response_common(self, result, desc, data=None):
+    def response_common(self, result, desc, data=None, log_extra_dict=None):
         """
         :Description: 输出公共json模型
         :param result: 返回结果标识
@@ -343,24 +361,29 @@ class BaseHandler(tornado.web.RequestHandler):
         template_value['desc'] = desc
         template_value['data'] = data
 
-        self.http_response(JsonHelper.json_dumps(template_value))
+        self.http_response(JsonHelper.json_dumps(template_value),
+                           log_extra_dict)
 
-    def http_response(self, content):
+    def http_response(self, content, log_extra_dict=None):
         """
         :Description: 将字符串返回给客户端
         :param content: 内容字符串
         :return: 将字符串返回给客户端
         :last_editors: ChenXiaolei
         """
+        extra = {
+            "extra": {
+                "request_code": self.request_code if hasattr(self, "request_code") else "",
+                "handler": self.__class__.__name__,
+                "action_mode": "output"
+            }
+        }
+
+        if log_extra_dict and type(log_extra_dict) == dict:
+            extra["extra"] = dict(extra["extra"], **log_extra_dict)
+
         content_log_info = f"http_output:{content}"
-        self.logger_http.info(content_log_info,
-                              extra={
-                                  "extra": {
-                                      "request_code": self.request_code,
-                                      "handler": self.__class__.__name__,
-                                      "action_mode": "output"
-                                  }
-                              })
+        self.logger_http.info(content_log_info, extra=extra)
         self.write(content)
 
     def response_json_success(self, data=None, desc='success'):
@@ -502,7 +525,7 @@ def filter_check_params(must_params=None):
     :last_editors: ChenXiaolei
     """
     def check_params(handler):
-        def wrapper(self, **args):
+        def wrapper(self, *args):
             self.request_params = {}
             must_array = []
             if type(must_params) == str:
@@ -530,8 +553,80 @@ def filter_check_params(must_params=None):
                             must_param] == "":
                         self.response_json_error_params()
                         return
-            return handler(self, **args)
+            return handler(self, *args)
 
         return wrapper
 
     return check_params
+
+
+def filter_check_sign(sign_key, sign_lower=False, reverse=False, is_sign_key=False, expired_seconds=None, exclude_params=None):
+    """
+    :description: http请求签名验证装饰器
+    :param sign_key: 参与签名的私钥
+    :param reverse: 是否反排序 False:升序 True:降序
+    :param is_sign_key: 参数名是否参与签名(默认False不参与)
+    :param expired_seconds: 接口timestamp过期时间(秒)
+    :param exclude_params: 不参与签名的参数,支持list,str(英文逗号分隔)
+    :last_editors: ChenXiaolei
+    """
+    def check_sign(handler):
+        def wrapper(self, *args):
+            # 签名参数
+            sign_params = {}
+            # 获取排除不需要签名的字段
+            exclude_array = []
+            if type(exclude_params) == str:
+                exclude_array = exclude_params.split(",")
+            if type(exclude_params) == list:
+                exclude_array = exclude_params
+            # 获取签名参数
+            if not hasattr(self, "request_params"):
+                if "Content-Type" in self.request.headers and self.request.headers[
+                        "Content-type"].lower().find(
+                            "application/json") >= 0 and self.request.body:
+                    json_params = {}
+                    try:
+                        json_params = json.loads(self.request.body)
+                    except:
+                        self.response_json_error_params()
+                        return
+                    if json_params:
+                        for field in json_params:
+                            sign_params[field] = json_params[field]
+                else:
+                    for field in self.request.arguments:
+                        sign_params[field] = self.get_param(field)
+            else:
+                sign_params = self.request_params
+
+            if not sign_params or len(sign_params) < 2 or "timestamp" not in sign_params or "sign" not in sign_params:
+                self.response_json_error_params("sign params error!")
+                return
+
+            sign_timestamp = int(sign_params["timestamp"])
+
+            if expired_seconds and (not sign_timestamp or TimeHelper.add_seconds_by_timestamp(sign_timestamp, expired_seconds) < TimeHelper.get_now_timestamp() or sign_timestamp > TimeHelper.add_seconds_by_timestamp(second=expired_seconds)):
+                self.response_json_error("请求已失效.")
+                return
+
+            # 排除签名参数
+            if exclude_params:
+                for exclude_key in exclude_params:
+                    if exclude_key in sign_params:
+                        del sign_params[exclude_key]
+            # 构建签名
+            build_sign = SignHelper.params_sign_md5(
+                sign_params, sign_key, sign_lower, reverse, is_sign_key)
+
+            if not build_sign or build_sign != sign_params["sign"]:
+                print(
+                    f"http请求验签不匹配,收到sign:{sign_params['sign']},构建sign:{build_sign} 加密明文信息:{SignHelper.get_sign_params_str(sign_params,sign_key,reverse,is_sign_key)}")
+                self.response_json_error("sign error!")
+                return
+
+            return handler(self, *args)
+
+        return wrapper
+
+    return check_sign
